# Makefile.tcl ---
# -------------------------------------------------------------------------
#   Purpose:
#       Create (*)starkit and application binaries
#       for unix and windows. This makefile might be used to
#       "cross compile" binaries for any target OS.
# 
#   Copyright(c) 2016,  Johann Oberdorfer
#                       mail-to: johann.oberdorfer@googlemail.com
# -------------------------------------------------------------------------
# This source file is distributed under the BSD license.

# to-do:
# - button to clean temp file
# - properties dialog to specify various css templates


package require Tk
wm withdraw .

if {$tcl_platform(platform) == "windows"} {
	console show
	console eval {wm protocol . WM_DELETE_WINDOW {exit}}
}

# main entry point:
set THIS_APP    [file normalize [file dirname [info script]]]
set TCLKIT_DIR  [file join $THIS_APP "../tclkit"]
set INSTALL_DIR [file join $THIS_APP "../Apps"]


# unix / win / osx - *edit* to reflect your build platform
# you are currently running on:
# ---------------------------------------------------------

set OSX_KIT [file join $TCLKIT_DIR "Darwin_kbsvq8.6-gui"]
set WIN_KIT [file join $TCLKIT_DIR "WindowsNT_kbsvq8.6-gui.exe"]
set TCL_KIT [file join $TCLKIT_DIR "WindowsNT_kbsvq8.6-cli.exe"]

set SDXUTIL [file join $TCLKIT_DIR "sdx.exe"]
set UPXUTIL [file join $TCLKIT_DIR "upx.exe"]


set VER "01"
set VFS "Release${VER}"
set APP "STLConverter"


# default operation mode
if {$argc == 0} {
	set argv "win"
}


proc build_win {} {

	global APP VFS SDXUTIL TCL_KIT UPXUTIL

	puts "Creating windows executable: ${APP}.exe ..."; update

	file delete -force ${APP}.exe
	exec $SDXUTIL wrap ${APP}.exe -vfs $VFS -runtime $TCL_KIT
	
	# compressing the exe...
	puts "Running UPX to compress executable ..."; update
	exec $UPXUTIL ${APP}.exe
}

proc build_osx {} {

	global APP VFS SDXUTIL OSX_KIT

	puts "Creating osx executable: ${APP}.osx ..."; update

	file delete -force ${APP}.osx
	exec $SDXUTIL wrap ${APP}.osx -vfs $VFS -runtime $OSX_KIT
		
	
	puts "Establishing required bundle directory structure ..."
	file mkdir ${APP}.app
	cd ${APP}.app
	file mkdir Contents
	cd Contents
		
	puts "Creating application specific Info.plist ..."
	file copy -force ../../macbundle/Info.plist ./Info.plist

	file mkdir MacOS
	file copy -force ../../${APP}.osx ./MacOS
	file mkdir Resources
	file copy -force ../../macbundle/${APP}.icns ./Resources
	cd ../..
	file delete -force ${APP}.osx
}

proc build_sdx {} {

	global TCL_KIT SDXUTIL TCL_KIT


	puts "Creating windows executable: sdx.exe ..."; update

	file delete -force sdx.exe
	exec $TCL_KIT $SDXUTIL wrap sdx.exe -vfs $SDXUTIL -runtime $TCL_KIT
}

set t0 [clock milliseconds]

switch -- $argv {
	"win" {	build_win }
	"osx" {	build_osx }
	"sdx" {	build_sdx }

	"all" {
		build_win
		build_osx
	}
	
	default {
		puts "Unknown or missing argument!"
	}
}

puts "Done - [expr ( [clock milliseconds] - $t0 ) / 1000.0] sec."
