# !/usr/bin/ksh
# next line starts wish \
exec wish "$0" "$@"

# -----------------------------------------------------------------------------
# (c) 2018, Johann Oberdorfer - Engineering Support | CAD | Software
#     johann.oberdorfer [at] gmail [dot] com
#     www.johann-oberdorfer.eu
# -----------------------------------------------------------------------------
# This source file is distributed under the BSD license.
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#   See the BSD License for more details.
# -----------------------------------------------------------------------------
# -----------------------------------------------------------------------------
# Revision history:
# 18-01-11: J.Oberdorfer, initial release
# 22-02-20: Johann, bug fixed:
#           no tk required here as the tk event manager causes kind of
#           asynchronous behavior, thanks to Nick Bowler who reported
#           this bug, makefile corrected as well
# -----------------------------------------------------------------------------
# -----------------------------------------------------------------------------


if {[catch {
	package require starkit
	if {[starkit::startup] eq "sourced"} { return } }]} {

	namespace eval ::starkit {
		if {[set this [info script]] == ""} {
			set this [info nameofexecutable]
		}
		variable topdir [file normalize [file dirname $this]]
	}
}


# where to find required packages:
set auto_path [linsert $auto_path 0 [file join $::starkit::topdir "lib"]]

package require stlutil


proc usage {} {
	puts \
"
Program usage:
--------------

	[file tail [info nameofexecutable]] \[options\]

	options:
		-stlfile file_name ..... specify a valid STL file
	
	Under windows it is also possible to drag and drop an STL
	file onto the program's icon to convert from ascii to binary file format
	and vice versa.
	
	Note: The main purpose of this utility function is to convert
	      STL files from ascii to binary format to save space and to gain
		  performance in the overall process chain.
		  Nevertheless it is also possible to convert the other way around
		  from binary to ascii (for whatever reason).

	The program automatically detects the file format and uses a different
	name for the output file, which will be one of:
       - \[*-binary.stl] ... ascii to binary
       - \[*-ascii.stl]  ... binary to ascii


Open source software:
---------------------

	(c) 2018, Johann Oberdorfer - Engineering Support | CAD | Software
		mail: johann.oberdorfer \[at\] gmail \[dot\] com
		web:  www.johann-oberdorfer.eu

	This software is distributed under the BSD license.
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the BSD License for more details.
"
}


proc OpenSTL {file_name} {

	# open a file (.xls, .pdf, ...)
	# with it's usual application:
	# ------------------------------------------
	set command [list {*}[auto_execok start] {}]
	exec {*}$command $file_name &
	# -------------------------------------------
}

proc main {argc argv} {

	# argument processing...
	# https://wiki.tcl-lang.org/1730
	#
	set arglen [llength $argv]
	set index 0
	
	while {$index < $arglen} {
		set arg [lindex $argv $index]

		# see if the 1st argument is a valid file (!)
		if { [info exists arg] && [file exists $arg] } {
			set args(-stlfile) $arg
			break
		}
		
		switch -exact $arg {
			-stlfile {
				set args($arg) [lindex $argv [incr index]]
			}
			-dummy {
				set args($arg) [lindex $argv [incr index]]
			}
			default {}
		}
		incr index
	}

	if { ![info exists args(-stlfile)] } {
		usage
		return
	}

	# here we go ...
	stlutil::convert_stl_file $args(-stlfile)
}

# here we go...
# note:
#   as we use wish starkit executable from kbs project
#   hosted on sourceforge, we can use "exit 0" as return sequence
#



# 22-02-20: Johann, bug fixed:
# tcl interpreter used, no tk required!
# catch {
#	wm withdraw .
#	console show
#	console eval {wm protocol . WM_DELETE_WINDOW {exit 0}}
# }

# --------------
main $argc $argv
# --------------

